@@ -1,21 +1,18 @@
 import logging
-from pathlib import Path
 
 from easyconfig import BaseModel
-from pydantic import Extra, Field, validator
+from pydantic import Field, field_validator
 
 
 class LoggingSettings(BaseModel):
     level: str = Field('INFO', description='Log level')
-    file: Path = Field('sml2mqtt.log', description='Log file path (absolute or relative to config file)')
+    file: str = Field('sml2mqtt.log', description='Log file path (absolute or relative to config file) or "stdout"')
 
-    class Config:
-        extra = Extra.forbid
-
-    @validator('level')
+    @field_validator('level')
     def validate_logging(cls, value):
         if value not in logging._nameToLevel:
-            raise ValueError(f'Level must be one of {", ".join(logging._nameToLevel)}')
+            msg = f'Level must be one of {", ".join(logging._nameToLevel)}'
+            raise ValueError(msg)
         return value
 
     def set_log_level(self) -> int:
