@@ -1,13 +1,15 @@
 from asyncio import sleep
-from typing import Optional
+from types import TracebackType
 
 
 class DynDelay:
-    def __init__(self, min_delay: float, max_delay: float, start_delay: Optional[float] = None):
+    def __init__(self, min_delay: float, max_delay: float, start_delay: float | None = None) -> None:
         if min_delay < 0:
-            raise ValueError(f'min_delay must be >= 0: {min_delay}')
+            msg = f'min_delay must be >= 0: {min_delay}'
+            raise ValueError(msg)
         if max_delay <= min_delay:
-            raise ValueError(f'max_delay must be >= min_delay: {max_delay}')
+            msg = f'max_delay must be >= min_delay: {max_delay}'
+            raise ValueError(msg)
 
         self.min = min_delay
         self.max = max_delay
@@ -17,21 +19,21 @@ class DynDelay:
 
         self.curr = max(min(start_delay, max_delay), min_delay)
 
-    async def wait(self):
+    async def wait(self) -> None:
         await sleep(self.curr)
 
-    def increase(self):
+    def increase(self) -> None:
         self.curr = min(self.max, self.curr * 2)
         if not self.curr:
             self.curr = 1
 
-    def reset(self):
+    def reset(self) -> None:
         self.curr = self.min
 
-    async def __aenter__(self):
+    async def __aenter__(self) -> None:
         await self.wait()
 
-    async def __aexit__(self, exc_type, exc_val, exc_tb):
+    async def __aexit__(self, exc_type: type[BaseException] | None, exc_val: BaseException | None, exc_tb: TracebackType | None) -> bool:  # noqa: E501
         if exc_type is None:
             self.reset()
         else:
