@@ -1,27 +1,35 @@
 import dataclasses
-from typing import Any, Callable, Final, List, Optional, Union
+from collections.abc import Callable, Generator
+from typing import Any, Final
 
 from sml2mqtt.__log__ import get_logger
 from sml2mqtt.config import OptionalMqttPublishConfig
 from sml2mqtt.mqtt import publish
 
-from .errors import MqttConfigValuesMissingError, TopicFragmentExpectedError
-
-pub_func: Callable[[str, Union[int, float, str], int, bool], Any] = publish
+from .errors import MqttConfigValuesMissingError, MqttTopicEmpty, TopicFragmentExpectedError
 
 
-def publish_analyze(topic: str, value: Union[int, float, str], qos: int, retain: bool):
+pub_func: Callable[[str, int | float | str, int, bool], Any] = publish
+
+
+def publish_analyze(topic: str, value: int | float | str, qos: int, retain: bool) -> None:
     get_logger('mqtt.pub').info(f'{topic}: {value} (QOS: {qos}, retain: {retain})')
 
 
+def patch_analyze() -> None:
+    global pub_func
+
+    pub_func = publish_analyze
+
+
 @dataclasses.dataclass
 class MqttCfg:
-    topic_full: Optional[str] = None
-    topic_fragment: Optional[str] = None
-    qos: Optional[int] = None
-    retain: Optional[bool] = None
+    topic_full: str | None = None
+    topic_fragment: str | None = None
+    qos: int | None = None
+    retain: bool | None = None
 
-    def set_config(self, config: Optional[OptionalMqttPublishConfig]):
+    def set_config(self, config: OptionalMqttPublishConfig) -> None:
         self.topic_full = config.full_topic
         self.topic_fragment = config.topic
         self.qos = config.qos
@@ -29,7 +37,7 @@ class MqttCfg:
 
 
 class MqttObj:
-    def __init__(self, topic_fragment: Optional[str] = None, qos: Optional[int] = None, retain: Optional[bool] = None):
+    def __init__(self, topic_fragment: str | None = None, qos: int | None = None, retain: bool | None = None) -> None:
 
         # Configured parts
         self.cfg = MqttCfg(topic_fragment=topic_fragment, qos=qos, retain=retain)
@@ -39,10 +47,10 @@ class MqttObj:
         self.retain: bool = False
         self.topic: str = ''
 
-        self.parent: Optional[MqttObj] = None
-        self.children: List[MqttObj] = []
+        self.parent: MqttObj | None = None
+        self.children: list[MqttObj] = []
 
-    def publish(self, value: Union[str, int, float, bytes]):
+    def publish(self, value: str | int | float) -> None:
         pub_func(self.topic, value, self.qos, self.retain)
 
     def update(self) -> 'MqttObj':
@@ -69,7 +77,17 @@ class MqttObj:
         else:
             if not self.cfg.topic_fragment:
                 raise TopicFragmentExpectedError()
-            self.topic = f'{self.parent.topic}/{self.cfg.topic_fragment}'
+
+            # The topmost topic may be empty
+            parts = []
+            if self.parent.topic:
+                parts.append(self.parent.topic)
+            if self.cfg.topic_fragment:
+                parts.append(self.cfg.topic_fragment)
+            self.topic = '/'.join(parts)
+
+            if not self.topic:
+                raise MqttTopicEmpty()
 
         # effective QOS
         self.qos = self.cfg.qos
@@ -82,12 +100,12 @@ class MqttObj:
             self.retain = self.parent.retain
         return self
 
-    def set_topic(self, topic: str) -> 'MqttObj':
+    def set_topic(self, topic: str | None) -> 'MqttObj':
         self.cfg.topic_fragment = topic
         self.update()
         return self
 
-    def set_config(self, cfg: Optional[OptionalMqttPublishConfig]) -> 'MqttObj':
+    def set_config(self, cfg: OptionalMqttPublishConfig | None) -> 'MqttObj':
         if cfg is None:
             return self
 
@@ -95,26 +113,35 @@ class MqttObj:
         self.update()
         return self
 
-    def create_child(self, topic_fragment: Optional[str] = None, qos: Optional[int] = None,
-                     retain: Optional[bool] = None) -> 'MqttObj':
+    def create_child(self, topic_fragment: str | None = None, qos: int | None = None,
+                     retain: bool | None = None) -> 'MqttObj':
         child = self.__class__(topic_fragment=topic_fragment, qos=qos, retain=retain)
         child.parent = self
         self.children.append(child)
         child.update()
         return child
 
+    def iter_objs(self) -> Generator['MqttObj', Any, None]:
+        yield self
+        for child in self.children:
+            yield from child.iter_objs()
+
 
 BASE_TOPIC: Final = MqttObj()
 
 
-def setup_base_topic(topic: str, qos: int, retain: bool):
+def setup_base_topic(topic: str, qos: int, retain: bool) -> None:
     BASE_TOPIC.cfg.topic_fragment = topic
     BASE_TOPIC.cfg.qos = qos
     BASE_TOPIC.cfg.retain = retain
     BASE_TOPIC.update()
 
 
-def patch_analyze():
-    global pub_func
+def check_for_duplicate_topics(obj: MqttObj) -> None:
+    log = get_logger('mqtt')
 
-    pub_func = publish_analyze
+    topics: set[str] = set()
+    for o in obj.iter_objs():
+        if (topic := o.topic) in topics:
+            log.warning(f'Topic "{topic:s}" is already configured!')
+        topics.add(topic)
