@@ -1,7 +1,9 @@
-from sml2mqtt.mqtt import MqttObj
+import pytest
+
+from sml2mqtt.mqtt import MqttObj, check_for_duplicate_topics
 
 
-def test_topmost(monkeypatch):
+def test_topmost(monkeypatch) -> None:
     parent = MqttObj('base', 2, True).update()
 
     assert parent.topic == 'base'
@@ -14,7 +16,14 @@ def test_topmost(monkeypatch):
     assert parent.retain is True
 
 
-def test_child_change(monkeypatch):
+def test_prefix_empty(monkeypatch) -> None:
+    parent = MqttObj('', 2, True).update()
+    child = parent.create_child('child')
+
+    assert (child.topic, child.qos, child.retain) == ('child', 2, True)
+
+
+def test_child_change(monkeypatch) -> None:
     parent = MqttObj('base', 2, True).update()
     child = parent.create_child('child')
 
@@ -41,3 +50,16 @@ def test_child_change(monkeypatch):
     parent.cfg.retain = False
     parent.update()
     assert (child.topic, child.qos, child.retain) == ('base/child', 0, False)
+
+
+@pytest.mark.ignore_log_warnings
+def test_check_for_duplicate_messages(caplog) -> None:
+    parent = MqttObj('base', 2, True).update()
+    parent.create_child('child')
+    parent.create_child('child')
+
+    check_for_duplicate_topics(parent)
+
+    msg = '\n'.join(x.msg for x in caplog.records)
+
+    assert msg == 'Topic "base/child" is already configured!'
